@@ -53,6 +53,7 @@ _encodings = (
     ("cp855"          , "IBM855"          , _("Cyrillic")),
     ("cp856"          , "IBM856"          , _("Hebrew")),
     ("cp857"          , "IBM857"          , _("Turkish")),
+    ("cp858"          , "IBM858"          , _("Western")),
     ("cp860"          , "IBM860"          , _("Portuguese")),
     ("cp861"          , "IBM861"          , _("Icelandic")),
     ("cp862"          , "IBM862"          , _("Hebrew")),
@@ -104,9 +105,11 @@ _encodings = (
     ("iso8859_8"      , "ISO-8859-8"      , _("Hebrew")),
     ("iso8859_9"      , "ISO-8859-9"      , _("Turkish")),
     ("iso8859_10"     , "ISO-8859-10"     , _("Nordic")),
+    ("iso8859_11"     , "ISO-8859-11"     , _("Thai")),
     ("iso8859_13"     , "ISO-8859-13"     , _("Baltic")),
     ("iso8859_14"     , "ISO-8859-14"     , _("Celtic")),
     ("iso8859_15"     , "ISO-8859-15"     , _("Western")),
+    ("iso8859_16"     , "ISO-8859-16"     , _("South European")),
     ("johab"          , "Johab"           , _("Korean")),
     ("koi8_r"         , "KOI8-R"          , _("Russian")),
     ("koi8_t"         , "KOI8-T"          , _("Tajik")),
